Unitary Simulator
=================

The :code:`UnitarySimulator` takes a given quantum circuits and combines the individual gates/operations into one unitary.


Usage in Python
###############

Available backend in the provider :code:`DDSIMProvider`:

- :code:`unitary_simulator` to combine the gates/operations in the circuit into one unitary.


Usage as Standalone Executable
##############################

.. warning::
    The unitary simulator is not exposed as standalone executable.
